@@ -10,11 +10,13 @@ void *memmove(void *dst, const void *src, size_t n)
 	char *q = dst;
 #if defined(__i386__) || defined(__x86_64__)
 	if (q < p) {
-		asm volatile ("cld ; rep ; movsb":"+c" (n), "+S"(p), "+D"(q));
+		asm volatile("cld ; rep ; movsb"
+			     : "+c" (n), "+S"(p), "+D"(q));
 	} else {
 		p += (n - 1);
 		q += (n - 1);
-		asm volatile ("std ; rep ; movsb":"+c" (n), "+S"(p), "+D"(q));
+		asm volatile("std ; rep ; movsb"
+			     : "+c" (n), "+S"(p), "+D"(q));
 	}
 #else
 	if (q < p) {
